==> apache-camel-3.14.3-src.zip: apache-camel-3.14.3/core/camel-core/src/test/java/org/apache/camel/component/scheduler/SchedulerMulticastParallelGreedyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.scheduler;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

public class SchedulerMulticastParallelGreedyTest extends ContextTestSupport {

    @Test
    public void testGreedy() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:parentComplete");
        mock.expectedMessageCount(1);

        // give it time to see if too many messages are sent if greedy kicks-in
        Thread.sleep(50);

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("scheduler:testBug?initialDelay=1&useFixedDelay=true&delay=20000&greedy=true&synchronous=true")
                    .multicast().parallelProcessing()
                        .log("test")
                    .end()
                    // this should result in the scheduler waiting its delay period before sending another exchange
                    .setProperty(Exchange.SCHEDULER_POLLED_MESSAGES, constant(false))
                    .to("mock:parentComplete");
            }
        };
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/core/camel-core/src/test/java/org/apache/camel/component/scheduler/SchedulerMulticastParallelGreedyTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.scheduler;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

public class SchedulerMulticastParallelGreedyTest extends ContextTestSupport {

    @Test
    public void testGreedy() throws Exception {
        MockEndpoint mock = getMockEndpoint("mock:parentComplete");
        mock.expectedMessageCount(1);

        // give it time to see if too many messages are sent if greedy kicks-in
        Thread.sleep(50);

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                from("scheduler:testBug?initialDelay=1&useFixedDelay=true&delay=20000&greedy=true&synchronous=true")
                    .multicast().parallelProcessing()
                        .log("test")
                    .end()
                    // this should result in the scheduler waiting its delay period before sending another exchange
                    .setProperty(Exchange.SCHEDULER_POLLED_MESSAGES, constant(false))
                    .to("mock:parentComplete");
            }
        };
    }
}
